dead-letter

dead-letter v4
WATCHING
Inbox
or click to browse
Converting
now:

written
skipped
errors

Last Job
Output
Report
State Selected Body Segmentation Path Confidence Client Hint Fallback Used
Drop more files to start another job
Settings

Workflow Paths

Inbox Path
Cabinet Path

Watch

Watch Path Override

Manual Job

Conversion Options

Strip junk
Verbose output

Content

Strip signatures Strip disclaimers Strip quoted headers

Images

Strip signature images Strip tracking pixels Embed inline images

Output

Include all headers Include raw HTML Disable calendar summary

Behavior

Allow plain-text fallback if HTML conversion fails Delete original .eml Dry run Generate conversion report
Inbox Path
Cabinet Path